#
# spec file for package python-django-webpack-loader
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-django-webpack-loader
Version:        3.1.1
Release:        1.1
Summary:        Django plugin to transparently use webpack
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/owais/django-webpack-loader
Source:         https://github.com/owais/django-webpack-loader/archive/%{version}.tar.gz
BuildRequires:  %{python_module Django >= 1.10}
BuildRequires:  %{python_module django-jinja}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
# tests are not currently run; transition unittest2
#BuildRequires:  %%{python_module unittest2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.10
Recommends:     python-django-jinja
BuildArch:      noarch
%python_subpackages

%description
webpack can be used to generate static bundles without Django's
staticfiles or opaque wrappers.

%prep
%setup -q -n django-webpack-loader-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
pushd tests
export DJANGO_SETTINGS_MODULE='app.settings'
# The tests are not working without nodejs webpack package
#%%pytest
popd

%files %{python_files}
%doc README.md CHANGELOG.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 3.1.1:
  * Add support for Django 5.1
* Sun Apr  7 2024 Dirk Müller <dmueller@suse.com>
- update to 3.1.0:
  * Support `webpack_asset` template tag to render transformed
    assets URL: `{%% webpack_asset 'path/to/original/file' %%} ==
    "/static/assets/resource-3c9e4020d3e3c7a09c68.txt"`
* Thu Mar 28 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 3.0.1:
  * Added `skip_common_chunks` option to the `get_files()`
    template tag.
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.0:
  * Fix support for `publicPath: auto` in Webpack config
  * Add support for Python 3.12
  * Add support for Django 5.0
* Tue Jun 20 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * Add support for Django 4.2
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * Update examples to use `webpack-bundle-tracker@2.0.0` API and
    keep version parity with it
  * Update Django to 3.2.19
  * Add mocked `get_assets` method to `FakeWebpackLoader` for
    usage in tests
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.8.1:
  * Add a `FakeWebpackLoader` for running tests
* Fri Jan 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.8.0:
  * Add compatibility for Django 4.1 and Python 3.10
- update to 1.7.0:
  * Bump django to 3.2.15
- update to 1.6.0:
  * Add a setting to configure skip common chunks behaviour globally
  * Bump django from 3.2.12 to 3.2.13
  * Add support for Django 4.0
- update to 1.5.0:
  * Added support for Subresource Integrity
  * Bump django from 3.2.7 to 3.2.12
  * Fix get_files on readme
  * Use r-prefixed strings in IGNORE
  * Fix small typo in README.md
  * Use assertNotEqual instead of assertNotEquals for Python 3.11
    compatibility
  * Readme revamp
- update to 1.4.1:
  * Fixes #300, failsafe request checking #301
- update to 1.4.0:
  * Bump django from 3.2.4 to 3.2.5 #299
  * Add issue templates #293
  * Add skip_common_chunks functionality #297
- update to 1.3.0:
  * Add option for rel="preload" in JS/CSS tags #203
  * Add option for extension appending in the url files #135
  * Fixes RemovedInDjango41Warning #290
  * Applies IGNORE setting before checking assets #286
  * Removed type from link and script tags per #152
  * NOTE: Skipped version 1.2.0 to match `webpack-bundle-tracker` version
- update to 1.1.0:
  * Added compatibility with `webpack-bundle-tracker@1.1.0`
  * Removes bower references in project
  * Fix jinja configuration example in README.md
- update to 1.0.0:
  * Added support for custom loader classes
  * Added compatibility with `webpack-bundle-tracker@1.0.0-alpha.1`
  * Updated and corrected examples
  * Updated Python and Django supported versions on tests
* Mon Jun  1 2020 pgajdos@suse.com
- do not require unittest2 for build, tests are currently not run
* Fri Apr  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.0:
  * Added support for custom loader classes
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Thu May  2 2019 Martin Herkt <9@cirno.systems>
- Init, 0.6.0
